<?php
/**
 * WeCodeArt Framework.
 *
 * WARNING: This file is part of the core WeCodeArt Framework. DO NOT edit this file under any circumstances.
 * Please do all modifications in the form of a child theme.
 *
 * @package 	WeCodeArt Framework
 * @subpackage 	Comment Body Template
 * @since 	    4.0.2
 * @version	    5.0.0
 */

defined( 'ABSPATH' ) || exit;

use WeCodeArt\Markup\SVG;

SVG::add_icon( 'pencil', [
    'viewBox'   => '0 0 576 512',
    'paths'     => 'M402.3 344.9l32-32c5-5 13.7-1.5 13.7 5.7V464c0 26.5-21.5 48-48 48H48c-26.5 0-48-21.5-48-48V112c0-26.5 21.5-48 48-48h273.5c7.1 0 10.7 8.6 5.7 13.7l-32 32c-1.5 1.5-3.5 2.3-5.7 2.3H48v352h352V350.5c0-2.1.8-4.1 2.3-5.6zm156.6-201.8L296.3 405.7l-90.4 10c-26.2 2.9-48.5-19.2-45.6-45.6l10-90.4L432.9 17.1c22.9-22.9 59.9-22.9 82.7 0l43.2 43.2c22.9 22.9 22.9 60 .1 82.8zM460.1 174L402 115.9 216.2 301.8l-7.3 65.3 65.3-7.3L460.1 174zm64.8-79.7l-43.2-43.2c-4.1-4.1-10.8-4.1-14.8 0L436 82l58.1 58.1 30.9-30.9c4-4.2 4-10.8-.1-14.9z'
] );
/**
 * @param   array   $author
 * @param   string  $awaiting
 * @param   array   $args
 * @param   object  $comment
 * @param   int     $depth
 */
?>
<div class="comment__body mb-3">
    <?php

    /**
     * Comment Hook - Top 
     */
    do_action( 'wecodeart/hook/comment/top', $comment );
        
    ?>
    <div class="row">
        <div class="col-auto">
            <figure class="comment__gravatar rounded shadow-sm border border-light p-1 mb-0"><?php
            
                echo get_avatar(
                    $comment,
                    $args['avatar_size'],
                    '',
                    sprintf( esc_html__( '%s\'s gravatar', 'wecodeart' ), $comment->comment_author )
                );
                
            ?></figure>
        </div>
        <div class="col align-self-center">
            <?php

                edit_comment_link( 
                    SVG::compile( 'pencil' ),
                    '<span class="comment-edit float-end" data-toggle="tooltip" title="' . esc_html__( 'Edit', 'wecodeart' ) . '">', '</span>'
                );
            
            ?>
            <div class="comment__author"><?php
                
                echo wp_kses_post( $author ); 
            
                if( (bool) $by_author )
                    printf(
                        ' &mdash; <span class="badge bg-primary rounded-pill">%s</span>',
                        esc_html__( 'Post Author', 'wecodeart' )
                    );

            ?></div>
            <time class="comment__date text-muted" itemprop="dateCreated" datetime="<?php

                echo esc_attr( get_comment_date( DATE_W3C ) );

            ?>"><?php

                echo esc_html( implode( ' ', [ get_comment_date(), __( 'at', 'wecodeart' ), get_comment_time() ] ) );

            ?></time>
        </div>
        <div class="col-12 mt-3">
            <?php if ( ! $comment->comment_approved ) : ?>
            <p class="callout"><?php
            
                esc_html_e( 'Your comment is awaiting moderation.', 'wecodeart' );
                
            ?></p>
            <?php endif; ?>
            <div class="comment__content p-3 border rounded" itemprop="text"><?php

                echo wp_kses_post( $comment->comment_content );

            ?></div>
            <?php
            
                comment_reply_link( array_merge( $args, [
                    'depth'  => $depth,
                    'before' => '<span class="comment-reply float-end me-3">',
                    'after'  => '</span>',
                ] ) );

            ?>
        </div>
    </div>
    <?php
        
    /**
     * Comment Hook - Bottom 
     */
    do_action( 'wecodeart/hook/comment/bottom', $comment );
    
    ?>
</div>