<?php
/**
 * WeCodeArt Framework.
 *
 * WARNING: This file is part of the core WeCodeArt Framework. DO NOT edit this file under any circumstances.
 * Please do all modifications in the form of a child theme.
 *
 * @package 	WeCodeArt Framework
 * @subpackage 	Author Box Template
 * @since 		3.0.3
 * @version		5.0.0
 */

defined( 'ABSPATH' ) || exit();

use WeCodeArt\Markup\SVG;
use function WeCodeArt\Functions\get_prop;

$classnames = [ 'wp-block-post-author' ];

if( $value = get_prop( $attributes, 'className', false ) ) {
    $classnames[] = $value;
}

if( $value = get_prop( $attributes, 'textAlign', false ) ) {
    $classnames[] = 'text-' . $value;
}

?>
<div class="<?php echo esc_attr( implode( ' ', $classnames ) ); ?>">
	<h3 class="wp-block-post-author__headline mb-3"><?php
			
		SVG::render( 'user' );
		
		?><span class="ms-2"><?php
		
			if( $byline = get_prop( $attributes, 'byline', false ) ) {
				echo wp_kses_post( $byline );
			} else {
				printf( esc_html__( 'About %s', 'wecodeart' ), sprintf(
					'<a href="%s" rel="author">%s</a>',
					$author->url,
					$author->name
				) );
			}

		?></span>
	</h3>
	<div class="row">
		<div class="wp-block-post-author__gravatar col-12 col-sm-auto"><?php

			echo get_avatar(
				$author->id,
				get_prop( $attributes, 'avatarSize', 90 ), 
				'',
				sprintf( esc_html__( '%s`s avatar', 'wecodeart' ), $author->name ),
				[
					'class' => 'img-thumbnail shadow-sm'
				]
			);

		?></div>
		<div class="wp-block-post-author__description col mt-4 mt-sm-0"><?php
		
			echo wp_kses_post( $author->description );
			
			if( isset( $social ) && is_array( $social ) ) {
				$classnames = [ 'wp-block-post-author__social', 'row', 'gx-2' ];
				if( $value = get_prop( $attributes, 'textAlign', false ) ) {
					$classnames[] = 'justify-content-' . $value;
				}
			?>
			<div class="<?php echo esc_attr( implode( ' ', $classnames ) ); ?>"><?php
				foreach( $social as $item ) {
					$key = strtolower( $item['title'] );
					$classes = [ 'wp-block-post-author__social-item', 'wp-block-post-author__social-item--' . $key, 'col-auto' ];
				?>
				<a class="<?php echo esc_attr( implode( ' ', $classes ) ); ?>"
					href="<?php echo esc_url( $item['url'] ); ?>"
					target="<?php echo esc_attr( $item['target'] ); ?>"
					rel="<?php echo ( $item['target'] === '_self' ) ? 'follow' : 'nofollow' ; ?>"><?php 
					
					SVG::render( $item['icon'] );

				?></a>
				<?php } ?>
			</div>
			<?php } ?>
		</div>
	</div>
</div>