<?php
/**
 * WeCodeArt Framework.
 *
 * WARNING: This file is part of the core WeCodeArt Framework. DO NOT edit this file under any circumstances.
 * Please do all modifications in the form of a child theme.
 *
 * @package 	WeCodeArt Framework
 * @subpackage 	Core\Entry
 * @copyright   Copyright (c) 2021, WeCodeArt Framework
 * @since 		3.5
 * @version		5.0.0
 */

namespace WeCodeArt\Core;

defined( 'ABSPATH' ) || exit();

use WeCodeArt\Core\Loops;
use WeCodeArt\Core\Pagination;
use WeCodeArt\Markup;
use WeCodeArt\Singleton;
use WeCodeArt\Markup\SVG;
use function WeCodeArt\Functions\get_prop;

/**
 * Handles WP CPT outputs
 */
class Entry {

	use Singleton;

	/**
	 * Send to Constructor
	 * @since 3.6.2
	 */
	public function init() {
		add_filter( 'the_password_form',	[ $this, 'render_pasword_protected' ] );
		add_filter( 'post_class',			[ $this, 'post_classes' ] );
		add_image_size( 'wca_featured', 500, 300, false );

		/**
		 * Child classes
		 */
		Entry\Comments::get_instance();
		Entry\Pagination::get_instance();
	}

	/**
	 * Return the content for No Posts
	 *
	 * @since	3.5
	 * @version	5.0.0
	 *
	 * @return 	void
	 */
	public function render_pasword_protected( $template ) {
		$template = wecodeart_template( 'entry/protected', [], false );
		$template = trim( preg_replace( '/\s+/', ' ', $template ) );
		$template = preg_replace( '/>\s*</', '><', $template );
		return $template;
	}

	/**
	 * Filter classes to the array of post classes.
	 *
	 * @param 	array $classes Classes for the post.
	 * 
	 * @return 	array
	 */
	public function post_classes( $classes ) {
		if ( is_admin() ) {
			return $classes;
		}
		
		// Add "entry" to the post class array.
		$classes[] = 'entry';

		// Remove "hentry" from post class array.
		$classes = array_diff( $classes, [ 'hentry' ] );
		
		return $classes;
	}
}