<?php
/**
 * WeCodeArt Framework.
 *
 * WARNING: This file is part of the core WeCodeArt Framework. DO NOT edit this file under any circumstances.
 * Please do all modifications in the form of a child theme.
 *
 * @package 	WeCodeArt Framework
 * @subpackage 	Support\CF7\Modules\Module
 * @copyright   Copyright (c) 2021, WeCodeArt Framework
 * @since 		5.0.0
 * @version		5.0.0
 */

namespace WeCodeArt\Support\Plugins\CF7\Modules;

defined( 'ABSPATH' ) || exit;

use WeCodeArt\Markup;
use WeCodeArt\Singleton;

/**
 * Checkbox Fields.
 */
class Checkbox extends Module {

	use Singleton;

	/**
	 * Module vars.
	 *
	 * @var mixed
	 */
	protected $name     = 'checkbox';
	protected $fields   = [ 'checkbox', 'checkbox*', 'radio' ];

	/**
	 * Return field HTML.
	 *
	 * @param   object $tag
     * 
	 * @return  string Rendered field output.
	 */
	public function get_html( $tag ) {
		if ( empty( $tag->name ) ) {
            return '';
        }

        $attrs = [];

        $validation_error   = wpcf7_get_validation_error( $tag->name );
        $class              = explode( ' ', wpcf7_form_controls_class( $tag->type ) );
    
        if ( $validation_error ) {
            $class[] = 'wpcf7-not-valid';
            $attrs['aria-describedby'] = wpcf7_get_validation_error_reference( $tag->name );
        }
    
        $is_inline      = $tag->has_option( 'inline' );
        $exclusive      = $tag->has_option( 'exclusive' );
        $first_as_label = $tag->has_option( 'first_as_label' );
        // To be implemented
        // $free_text      = $tag->has_option( 'free_text' );
        $multiple       = false;
    
        if ( 'checkbox' == $tag->basetype ) {
            $multiple = ! $exclusive;
        } else { // radio
            $exclusive = false;
        }
    
        if ( $exclusive ) {
            $class[]= 'wpcf7-exclusive-checkbox';
        }
    
        $attrs['name']  = $tag->name;

        if( $tag->get_id_option() ) { 
            $attrs['id']    = $tag->get_id_option();
        }
        
        $attrs['class'] = join( ' ', array_filter( [
            $is_inline ? 'form-check-inline' : '',
            $tag->get_class_option( join( ' ', $class ) ),
        ] ) );
    
        $values = $tag->values;
        $labels = $tag->labels;

        if( $first_as_label ) {
            array_shift( $values );
            array_shift( $labels );
        }
    
        $default_choice = $tag->get_default_option( null, [ 'multiple' => $multiple ] );
        $choices    = [];
        $hangover   = wpcf7_get_hangover( $tag->name, $multiple ? [] : '' );

        if ( $hangover ) {
            $selected = $hangover;
        } else {
            $selected = $default_choice;
        }

        if( $selected ) {
            $attrs['value'] = $selected;
        }

        $label = $first_as_label ? (string) reset( $tag->values ) : false;

        foreach ( $values as $key => $value ) $choices[ $value ] = isset( $labels[$key] ) ? $labels[$key] : $value;
    
        $html = Markup::wrap( 'cf7-checkbox-field', [ [
            'tag' 	=> 'span',
            'attrs' => [
                'class' => self::get_wrap_class( $tag )
            ]
        ] ], 'wecodeart_input', [ 'fieldset', [
            'type'      => $tag->basetype,
            'label'     => $label,
            'exclusive' => $exclusive,
            'attrs' 	=> $attrs,
            'choices'   => $choices,
            'messages' 	=> [
                'invalid' => $validation_error
            ]
        ] ], false );

        return $html;
	}

    /**
	 * Get Module args.
	 *
	 * @return array
	 */
	protected function get_args() {
		return [
			'name-attr'         => true,
			'selectable-values' => true,
			'multiple-controls-container' => true,
		];
	}
}
