<?php
/**
 * WeCodeArt Framework.
 *
 * WARNING: This file is part of the core WeCodeArt Framework. DO NOT edit this file under any circumstances.
 * Please do all modifications in the form of a child theme.
 *
 * @package 	WeCodeArt Framework
 * @subpackage 	Support\CF7\Modules\Module
 * @copyright   Copyright (c) 2021, WeCodeArt Framework
 * @since 		5.0.0
 * @version		5.0.0
 */

namespace WeCodeArt\Support\Plugins\CF7\Modules;

defined( 'ABSPATH' ) || exit;

use WeCodeArt\Markup;
use WeCodeArt\Singleton;

/**
 * TextArea Fields.
 */
class TextArea extends Module {

	use Singleton;

	/**
	 * Module vars.
	 *
	 * @var mixed
	 */
	protected $name     = 'textarea';
	protected $fields   = [ 'textarea', 'textarea*' ];

	/**
	 * Return field HTML.
	 *
	 * @param   object $tag
     * 
	 * @return  string Rendered field output.
	 */
	public function get_html( $tag ) {
		if ( empty( $tag->name ) ) {
            return '';
        }
    
        $attrs = [];

        $validation_error   = wpcf7_get_validation_error( $tag->name );
        $class              = explode( ' ', wpcf7_form_controls_class( $tag->type, 'form-control' ) );
        
        if ( $validation_error ) {
            $class[] = 'wpcf7-not-valid';
            $attrs['aria-invalid'] 		= 'true';
            $attrs['aria-describedby'] 	= wpcf7_get_validation_error_reference( $tag->name );
        } else {
            $attrs['aria-invalid'] 		= 'false';
        }
    
        $attrs['cols'] 		= $tag->get_cols_option( '40' );
        $attrs['rows'] 		= $tag->get_rows_option( '10' );
        $attrs['maxlength'] = $tag->get_maxlength_option();
        $attrs['minlength'] = $tag->get_minlength_option();
    
        if ( $attrs['maxlength'] and $attrs['minlength'] and $attrs['maxlength'] < $attrs['minlength'] ) {
            unset( $attrs['maxlength'], $attrs['minlength'] );
        }
    
        $attrs['class']			= $tag->get_class_option( join( ' ', $class ) );
        $attrs['name']          = $tag->name;
        $attrs['tabindex'] 		= $tag->get_option( 'tabindex', 'signed_int', true );
        $attrs['autocomplete'] 	= $tag->get_option( 'autocomplete', '[-0-9a-zA-Z]+', true );

        if( $tag->get_id_option() ) { 
            $attrs['id']    = $tag->get_id_option();
        }

        if ( $tag->has_option( 'readonly' ) ) {
            $attrs['readonly'] = 'readonly';
        }
    
        if ( $tag->is_required() ) {
            $attrs['required'] = true;
            $attrs['aria-required'] = 'true';
        }
    
        $label = $tag->has_option( 'first_as_label' ) ? (string) reset( $tag->values ) : false;
        $value = empty( $tag->content ) ? (string) end( $tag->values ) : $tag->content;
    
        if ( $tag->has_option( 'placeholder' ) or $tag->has_option( 'watermark' ) ) {
            $attrs['placeholder'] = $value;
            $value = '';
        }

	    $value = wpcf7_get_hangover( $tag->name, $tag->get_default_option( $value ) );
        $attrs['value'] = $value;

        $html = Markup::wrap( 'cf7-textarea-field', [ [
            'tag' 	=> 'span',
            'attrs' => [
                'class' => self::get_wrap_class( $tag )
            ]
        ] ], 'wecodeart_input', [ 'textarea', [
            'label' 	=> $label,
            'attrs' 	=> $attrs,
            'messages' 	=> [
                'invalid' => $validation_error
            ]
        ] ], false );

        return $html;
	}
}
